import { Injectable, Component, NgModule } from '@angular/core';
import { Http, Headers, ConnectionBackend, RequestOptions, HttpModule } from '@angular/http';
import { Subject } from 'rxjs/Rx';
import { Subject as Subject$1 } from 'rxjs/Subject';
import { LocalStorageService } from 'angular-2-local-storage';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Setting {
    /**
     * @param {?} key
     * @param {?} value
     */
    constructor(key, value) {
        this.key = key;
        this.value = value;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class AppConfig {
    /**
     * @param {?} http
     */
    constructor(http) {
        this.http = http;
        this.paths = [];
        this.config = [];
        this.env = null;
        this.subject = new Subject();
        this.initialized = this.subject.asObservable();
    }
    /**
     * @return {?}
     */
    getPresentationConfigs() {
        return this.config.filter(x => x.key.toLowerCase().endsWith("config"));
    }
    /**
     * @param {?} key
     * @return {?}
     */
    get(key) {
        let /** @type {?} */ setting = this.config.filter(x => x.key.toLowerCase() == key.toLowerCase());
        return setting.length > 0 ? setting[0].value : null;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    getEnv(key) {
        return this.env[key];
    }
    /**
     * @param {?} applicationName
     * @param {?} paths
     * @return {?}
     */
    addNavigationItems(applicationName, paths) {
        for (let /** @type {?} */ path of paths) {
            if (this.paths.filter(x => x.value.name == path.name).length == 0) {
                this.paths.push(new Setting(applicationName, { name: path.name, route: path.route }));
            }
        }
    }
    /**
     * @param {?} applicationName
     * @return {?}
     */
    fetchNavigationItems(applicationName) {
        return this.paths.filter(x => x.key === applicationName).map(x => new Setting(x.value.name, x.value.route));
    }
    /**
     * @param {?} settings
     * @param {?} env
     * @return {?}
     */
    initialize(settings, env) {
        this.config = this.config.concat(settings);
        this.env = env;
        this.subject.next(true);
    }
}
AppConfig.decorators = [
    { type: Injectable },
];
/** @nocollapse */
AppConfig.ctorParameters = () => [
    { type: Http, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const contentHeaders = new Headers();
contentHeaders.append('Accept', 'application/json');
contentHeaders.append('Content-Type', 'application/json');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LoaderService {
    constructor() {
        this.loaderSubject = new Subject$1();
        this.loaderState = this.loaderSubject.asObservable();
    }
    /**
     * @return {?}
     */
    show() {
        this.loaderSubject.next(/** @type {?} */ ({ show: true }));
    }
    /**
     * @return {?}
     */
    hide() {
        this.loaderSubject.next(/** @type {?} */ ({ show: false }));
    }
}
LoaderService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
LoaderService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LoaderComponent {
    /**
     * @param {?} loaderService
     */
    constructor(loaderService) {
        this.loaderService = loaderService;
        this.show = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.subscription = this.loaderService.loaderState
            .subscribe((state) => {
            this.show = state.show;
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
}
LoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'angular-loader',
                template: `<div [class.loader-hidden]="!show">
                    <div class="loader-overlay">
                            <div>
                                <mat-progress-bar color="warn" mode="indeterminate" *ngIf="show"></mat-progress-bar>
                            </div>
                    </div>
                </div>`,
                styles: [`.loader-hidden {
        visibility: hidden;
    }
    .loader-overlay {
        position: absolute;
        width:100%;
        top:0;
        left: 0;
        opacity: 1;
        z-index: 9999999999;
    }`],
            },] },
];
/** @nocollapse */
LoaderComponent.ctorParameters = () => [
    { type: LoaderService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class HttpIntegrationService {
    constructor() {
        this.subject = new Subject$1();
        this.OnError = this.subject.asObservable();
    }
    /**
     * @param {?} res
     * @return {?}
     */
    error(res) {
        this.subject.next(res);
    }
}
HttpIntegrationService.decorators = [
    { type: Injectable },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class InterceptedHttp extends Http {
    /**
     * @param {?} backend
     * @param {?} defaultOptions
     * @param {?} localStorageService
     * @param {?} loaderService
     * @param {?} httpIntegrationService
     */
    constructor(backend, defaultOptions, localStorageService, loaderService, httpIntegrationService) {
        super(backend, defaultOptions);
        this.localStorageService = localStorageService;
        this.loaderService = loaderService;
        this.httpIntegrationService = httpIntegrationService;
    }
    /**
     * @param {?} url
     * @param {?=} options
     * @return {?}
     */
    get(url, options) {
        this.showLoader();
        return super.get(url, this.getRequestOptionArgs(options))
            .do((res) => {
            this.onSuccess(res);
        }, (error) => {
            this.onError(error);
        })
            .finally(() => {
            this.onEnd();
        });
    }
    /**
     * @param {?} url
     * @param {?} body
     * @param {?=} options
     * @return {?}
     */
    post(url, body, options) {
        this.showLoader();
        return super.post(url, body, this.getRequestOptionArgs(options))
            .do((res) => {
            this.onSuccess(res);
        }, (error) => {
            this.onError(error);
        })
            .finally(() => {
            this.onEnd();
        });
    }
    /**
     * @param {?} url
     * @param {?} body
     * @param {?=} options
     * @return {?}
     */
    put(url, body, options) {
        this.showLoader();
        return super.put(url, body, this.getRequestOptionArgs(options))
            .do((res) => {
            this.onSuccess(res);
        }, (error) => {
            this.onError(error);
        })
            .finally(() => {
            this.onEnd();
        });
    }
    /**
     * @param {?} url
     * @param {?=} options
     * @return {?}
     */
    delete(url, options) {
        this.showLoader();
        return super.delete(url, this.getRequestOptionArgs(options))
            .do((res) => {
            this.onSuccess(res);
        }, (error) => {
            this.onError(error);
        })
            .finally(() => {
            this.onEnd();
        });
    }
    /**
     * @param {?=} options
     * @return {?}
     */
    getRequestOptionArgs(options) {
        if (options == null) {
            options = new RequestOptions();
        }
        if (options.headers == null) {
            options.headers = new Headers();
        }
        if (!options.withCredentials)
            this.createAuthorizationHeader(options.headers);
        return options;
    }
    /**
     * @param {?} headers
     * @return {?}
     */
    createAuthorizationHeader(headers) {
        if (this.localStorageService.get('id_token') != null) {
            headers.append('Authorization', this.localStorageService.get('id_token'));
        }
    }
    /**
     * @param {?} res
     * @return {?}
     */
    onSuccess(res) {
        console.log('Request successful');
    }
    /**
     * @param {?} res
     * @return {?}
     */
    onError(res) {
        console.log('Error, status code: ' + res.status);
        this.httpIntegrationService.error(res);
    }
    /**
     * @return {?}
     */
    onEnd() {
        this.hideLoader();
    }
    /**
     * @return {?}
     */
    showLoader() {
        this.loaderService.show();
    }
    /**
     * @return {?}
     */
    hideLoader() {
        this.loaderService.hide();
    }
}
InterceptedHttp.decorators = [
    { type: Injectable },
];
/** @nocollapse */
InterceptedHttp.ctorParameters = () => [
    { type: ConnectionBackend, },
    { type: RequestOptions, },
    { type: LocalStorageService, },
    { type: LoaderService, },
    { type: HttpIntegrationService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @param {?} xhrBackend
 * @param {?} requestOptions
 * @param {?} localStorageService
 * @param {?} loaderService
 * @param {?} httpIntegrationService
 * @return {?}
 */
function httpFactory(xhrBackend, requestOptions, localStorageService, loaderService, httpIntegrationService) {
    return new InterceptedHttp(xhrBackend, requestOptions, localStorageService, loaderService, httpIntegrationService);
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
if (!Array.prototype.add) {
    Array.prototype.add = function (item) {
        this.push(item);
    };
}
if (!Array.prototype.addRange) {
    Array.prototype.addRange = function (items) {
        items.forEach(x => this.push(x));
    };
}
if (!Array.prototype.remove) {
    Array.prototype.remove = function (item) {
        var /** @type {?} */ index = this.indexOf(item);
        this.splice(index, 0);
        return index != -1;
    };
}
if (!Array.prototype.where) {
    Array.prototype.where = function (func) {
        let /** @type {?} */ items = /** @type {?} */ (this.filter(func));
        return items;
    };
}
if (!Array.prototype.orderBy) {
    Array.prototype.orderBy = function (propertyExpression) {
        let /** @type {?} */ result = Array();
        var /** @type {?} */ compareFunction = (item1, item2) => {
            if (propertyExpression(item1) > propertyExpression(item2))
                return 1;
            if (propertyExpression(item2) > propertyExpression(item1))
                return -1;
            return 0;
        };
        for (var /** @type {?} */ i = 0; i < (/** @type {?} */ (this)).length; i++) {
            return (/** @type {?} */ (this)).sort(compareFunction);
        }
        return result;
    };
}
if (!Array.prototype.orderByDescending) {
    Array.prototype.orderByDescending = function (propertyExpression) {
        let /** @type {?} */ result = Array();
        var /** @type {?} */ compareFunction = (item1, item2) => {
            if (propertyExpression(item1) > propertyExpression(item2))
                return -1;
            if (propertyExpression(item2) > propertyExpression(item1))
                return 1;
            return 0;
        };
        for (var /** @type {?} */ i = 0; i < (/** @type {?} */ (this)).length; i++) {
            return (/** @type {?} */ (this)).sort(compareFunction);
        }
        return result;
    };
}
if (!Array.prototype.single) {
    Array.prototype.single = function (func = null) {
        let /** @type {?} */ items = this;
        if (func != null)
            items = /** @type {?} */ (this.filter(func));
        if (items.length > 1)
            throw new SequenceContainsMoreThanOneElementException();
        if (items.length == 0)
            throw new SequenceDoesNotContainException();
        return items[0];
    };
}
if (!Array.prototype.singleOrDefault) {
    Array.prototype.singleOrDefault = function (func = null) {
        let /** @type {?} */ items = this;
        if (func != null)
            items = /** @type {?} */ (this.filter(func));
        if (items.length > 1)
            throw new SequenceContainsMoreThanOneElementException();
        if (items.length == 0)
            return null;
        return items[0];
    };
}
if (!Array.prototype.first) {
    Array.prototype.first = function (func = null) {
        let /** @type {?} */ items = this;
        if (func != null)
            items = /** @type {?} */ (this.filter(func));
        if (items.any())
            return items[0];
        else
            throw new SequenceDoesNotContainException();
    };
}
if (!Array.prototype.firstOrDefault) {
    Array.prototype.firstOrDefault = function (func = null) {
        let /** @type {?} */ items = this;
        if (func != null)
            items = /** @type {?} */ (this.filter(func));
        if (items.length > 0)
            return items[0];
        else
            return null;
    };
}
if (!Array.prototype.last) {
    Array.prototype.last = function (func = null) {
        let /** @type {?} */ items = this.reverse();
        if (func != null)
            items = /** @type {?} */ (this.filter(func));
        items = /** @type {?} */ (this.filter(func));
        if (items.length > 1)
            return items[0];
        else
            throw new SequenceDoesNotContainException();
    };
}
if (!Array.prototype.lastOrDefault) {
    Array.prototype.lastOrDefault = function (func = null) {
        let /** @type {?} */ items = this.reverse();
        if (func != null)
            items = /** @type {?} */ (this.filter(func));
        if (items.length > 0)
            return items[0];
        else
            return null;
    };
}
if (!Array.prototype.any) {
    Array.prototype.any = function (func = null) {
        let /** @type {?} */ items = this;
        if (func != null)
            items = /** @type {?} */ (this.filter(func));
        return items.length > 0;
    };
}
if (!Array.prototype.all) {
    Array.prototype.all = function (func) {
        let /** @type {?} */ items = /** @type {?} */ (this.filter(func));
        return items.length == this.length;
    };
}
class SequenceDoesNotContainException extends Error {
    constructor() {
        super();
        Object.setPrototypeOf(this, SequenceDoesNotContainException.prototype);
    }
}
class SequenceContainsMoreThanOneElementException extends Error {
    constructor() {
        super();
        Object.setPrototypeOf(this, SequenceContainsMoreThanOneElementException.prototype);
    }
}
class ArrayExtensions {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
if (!String.prototype.fromCamelCase) {
    String.prototype.fromCamelCase = function () {
        return this.replace(/([a-z](?=[A-Z]))/g, '$1 ');
    };
}
class StringExtensions {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class CoreModule {
}
CoreModule.decorators = [
    { type: NgModule, args: [{
                imports: [HttpModule],
                declarations: [],
                providers: [AppConfig],
                exports: [LoaderComponent, AppConfig]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { CoreModule, LoaderComponent, httpFactory, AppConfig, Setting, contentHeaders, LoaderService, HttpIntegrationService, InterceptedHttp, ArrayExtensions, StringExtensions };
//# sourceMappingURL=easy-core.js.map
